pub struct ActorRuntime;Expand description
ActorRuntime
Coordinates the execution and lifecycle of a single WebAssembly actor within the Theater system.
ActorRuntime provides static methods for building and running actors. It manages the various
components that make up an actor’s execution environment, including handlers and communication
channels. It’s responsible for starting the actor, setting up its capabilities via handlers,
executing operations, and ensuring proper shutdown.
Implementations
Sourceimpl ActorRuntime
impl ActorRuntime
pub async fn build_actor_resources( id: TheaterId, name: String, wasm_bytes: Vec<u8>, pack_runtime: AsyncRuntime, chain: Arc<SyncRwLock<StateChain>>, handler_registry: HandlerRegistry, theater_tx: Sender<TheaterCommand>, operation_tx: Sender<ActorOperation>, info_tx: Sender<ActorInfo>, control_tx: Sender<ActorControl>, actor_phase_manager: ActorPhaseManager, actor_instance_wrapper: Arc<RwLock<Option<PackInstance>>>, initial_state: Value, ) -> Result<(ShutdownController, Vec<JoinHandle<()>>), ActorRuntimeError>
pub async fn start( id: TheaterId, name: String, wasm_bytes: Vec<u8>, pack_runtime: AsyncRuntime, chain: Arc<SyncRwLock<StateChain>>, handler_registry: HandlerRegistry, theater_tx: Sender<TheaterCommand>, operation_rx: Receiver<ActorOperation>, operation_tx: Sender<ActorOperation>, info_rx: Receiver<ActorInfo>, info_tx: Sender<ActorInfo>, control_rx: Receiver<ActorControl>, control_tx: Sender<ActorControl>, initial_state: Value, setup_result_tx: Option<Sender<Result<(), String>>>, )